tinyurl_shortener library
Classes
- TinyUrlException
- TinyUrlException-- thrown on each unsuccessful request to tinyurl api
- TinyUrlLinkData
- TinyUrlLinkData class that hold all the metadata of the link shortened. an instance of the class will be returned after each successful request to tinyurl apis containing all the data send by the api
- TinyUrlShortener
- class to work with TinyUrl links